PeripheralSignal

Trait PeripheralSignal 

pub trait PeripheralSignal<'d>: Sealed { }
The base of all peripheral signals.

This trait represents a signal in the GPIO matrix. Signals are converted or split from GPIO pins and can be connected to peripheral inputs and outputs.

All signals can be peripheral inputs, but not all output-like types should be allowed to be passed as inputs. This trait bridges this gap by defining the logic, but not declaring the signal to be an actual Input signal.

Implementors

Source

impl PeripheralSignal<'_> for Level

Available on crate feature unstable only.
Source

impl PeripheralSignal<'_> for NoPin

Available on crate feature unstable only.
Source

impl<'d> PeripheralSignal<'d> for GPIO0<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO1<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO2<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO3<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO4<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO5<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO6<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO7<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO8<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO9<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO10<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO11<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO12<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO13<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO14<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO15<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO16<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO17<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO18<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO19<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO20<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO21<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO22<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO23<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO25<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO26<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO27<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO32<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO33<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO34<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO35<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO36<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO37<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO38<'d>

Source

impl<'d> PeripheralSignal<'d> for GPIO39<'d>

Source

impl<'d> PeripheralSignal<'d> for AnyPin<'d>

Source

impl<'d> PeripheralSignal<'d> for Flex<'d>

Available on crate feature unstable only.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Source

impl<'d> PeripheralSignal<'d> for Input<'d>

Available on crate feature unstable only.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Source

impl<'d> PeripheralSignal<'d> for Output<'d>

Available on crate feature unstable only.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Source

impl<'d> PeripheralSignal<'d> for InputSignal<'d>

Available on crate feature unstable only.
Source

impl<'d> PeripheralSignal<'d> for OutputSignal<'d>

Available on crate feature unstable only.